==> media_folders-1.0.1.tar.gz: media_folders/tests/src/FunctionalJavascript/MediaFoldersWidgetUiTest.php <==
<?php

namespace Drupal\Tests\media_folders\FunctionalJavascript;

use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\field\Entity\FieldConfig;
use Drupal\field\Entity\FieldStorageConfig;
use Drupal\file\Entity\File;
use Drupal\FunctionalJavascriptTests\WebDriverTestBase;
use Drupal\media\Entity\Media;
use Drupal\media\MediaTypeInterface;
use Drupal\taxonomy\Entity\Term;
use Drupal\Tests\field_ui\Traits\FieldUiTestTrait;
use Drupal\Tests\media\Traits\MediaTypeCreationTrait;
use org\bovigo\vfs\vfsStream;

/**
 * Ensures that media UI works correctly.
 */
class MediaFoldersWidgetUiTest extends WebDriverTestBase {

  use FieldUiTestTrait;
  use MediaTypeCreationTrait;

  /**
   * Permissions for the admin user that will be logged-in for test.
   *
   * @var array
   */
  protected static $adminUserPermissions = [
    'access media overview',
    'administer media',
    'administer media fields',
    'administer media form display',
    'administer media display',
    'administer media types',
    'view media',
    'access content overview',
    'view all revisions',
    'administer content types',
    'administer node fields',
    'administer node form display',
    'administer node display',
    'bypass node access',
  ];

  /**
   * An admin test user account.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $adminUser;

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = [
    'system',
    'node',
    'field_ui',
    'views',
    'views_ui',
    'block',
    'taxonomy',
    'file',
    'media_library',
    'user',
    'media_folders',
  ];

  /**
   * Set default theme to stable.
   *
   * @var string
   */
  protected $defaultTheme = 'stable9';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->drupalPlaceBlock('local_actions_block');
    $this->drupalPlaceBlock('local_tasks_block');

    $term_values = [
      'parent' => [0],
      'name' => 'Test',
      'description' => '',
      'vid' => 'media_folders_folder',
    ];
    $term = Term::create($term_values);
    $term->save();

    $fileMediaType = $this->createMediaType('file', [
      'id' => 'document',
      'label' => 'Document',
    ]);

    $fileMedia = $this->generateMedia('test.pdf', $fileMediaType);
    $fileMedia->save();

    $this->adminUser = $this->drupalCreateUser(static::$adminUserPermissions);
    $this->drupalLogin($this->adminUser);

    $this->drupalCreateContentType(['type' => 'page', 'name' => 'Page']);

    $media_storage = FieldStorageConfig::create([
      'field_name' => 'field_media_field',
      'entity_type' => 'node',
      'type' => 'entity_reference',
      'cardinality' => FieldStorageDefinitionInterface::CARDINALITY_UNLIMITED,
      'settings' => [
        'target_type' => 'media',
      ],
    ]);
    $media_storage->save();
    $media_field = FieldConfig::create([
      'label' => 'Media',
      'field_storage' => $media_storage,
      'entity_type' => 'node',
      'bundle' => 'page',
      'settings' => [
        'handler' => 'default',
        'handler_settings' => [
          'target_bundles' => [
            'document' => 'document',
          ],
        ],
      ],
    ]);
    $media_field->save();
  }

  /**
   * Tests that the Media folders's widget selection works as expected.
   */
  public function testWidgetSelection(): void {
    $assert_session = $this->assertSession();
    $page = $this->getSession()->getPage();

    $this->drupalGet('/admin/structure/types/manage/page/form-display');
    $page->pressButton('Show row weights');
    $page->fillField('fields[field_media_field][region]', 'content');
    $page->fillField('fields[field_media_field][type]', 'media_folders_widget');
    $page->pressButton('Save');

    $this->drupalGet('/admin/structure/types/manage/page/form-display');
    $assert_session->pageTextContains('View mode: List view');

    $this->drupalGet('/admin/structure/types/manage/page/display');
    $page->fillField('fields[field_media_field][region]', 'content');
    $page->fillField('fields[field_media_field][type]', 'media_folders');
    $page->pressButton('Save');

    $this->drupalGet('/admin/structure/types/manage/page/display');
    $assert_session->pageTextContains('field_media_field');

    $this->drupalGet('/node/add/page');
    $assert_session->responseContains('type="submit" id="edit-field-media-field-open-button" name="field_media_field-media-folders-open-button" value="Add media"');
    $page->fillField('title[0][value]', 'Test');
    $page->pressButton('Add media');
    $assert_session->assertWaitOnAjaxRequest();
    $this->assertNotEmpty($assert_session->waitForElementVisible('css', '#drupal-modal'));
    $assert_session->responseContains('<div id="media-folders" class="widget');
    $assert_session->responseContains('<div class="folder folder-folder" data-id="1" data-uuid');

    $this->click('#explorer #navbar > ul li > div[data-id="1"] > a');
    $assert_session->assertWaitOnAjaxRequest();
    $assert_session->responseContains('<div class="folder folder-file" data-id="1" data-uuid');
    $this->click('.folder-file[data-id="1"] a.folder-icon');
    $page->pressButton('Insert selected');
    $this->assertNotEmpty($assert_session->waitForElementRemoved('css', '#drupal-modal'));
    $assert_session->assertWaitOnAjaxRequest();
    $assert_session->responseNotContains('<div id="media-folders" class="widget');
    $page->pressButton('Save');
    $assert_session->addressEquals('node/1');
    $this->drupalGet('/node/1');
    $assert_session->responseContains('<span class="file file--mime-application-pdf file--application-pdf">');
  }

  /**
   * Helper to generate a media item.
   *
   * @param string $filename
   *   String filename with extension.
   * @param \Drupal\media\MediaTypeInterface $media_type
   *   The media type.
   *
   * @return \Drupal\media\Entity\Media
   *   A media item.
   */
  protected function generateMedia($filename, MediaTypeInterface $media_type) {
    vfsStream::setup('drupal_root');
    vfsStream::create([
      'sites' => [
        'default' => [
          'files' => [
            $filename => str_repeat('a', 3000),
          ],
        ],
      ],
    ]);

    $file = File::create([
      'uri' => 'public://' . $filename,
    ]);
    $file->setPermanent();
    $file->save();

    return Media::create([
      'bundle' => $media_type->id(),
      'name' => $filename,
      'field_media_file' => [
        'target_id' => $file->id(),
      ],
      'field_folders_folder' => [
        'target_id' => 1,
      ],
    ]);
  }

}

==> media_folders-1.0.2.tar.gz: media_folders/tests/src/FunctionalJavascript/MediaFoldersWidgetUiTest.php <==
<?php

namespace Drupal\Tests\media_folders\FunctionalJavascript;

use Drupal\file\Entity\File;
use Drupal\FunctionalJavascriptTests\WebDriverTestBase;
use Drupal\media\Entity\Media;
use Drupal\media\MediaTypeInterface;
use Drupal\taxonomy\Entity\Term;
use Drupal\Tests\media\Traits\MediaTypeCreationTrait;
use org\bovigo\vfs\vfsStream;

/**
 * Ensures that media UI works correctly.
 */
class MediaFoldersWidgetUiTest extends WebDriverTestBase {
  use MediaTypeCreationTrait;

  /**
   * Permissions for the admin user that will be logged-in for test.
   *
   * @var array
   */
  protected static $adminUserPermissions = [
    'access media overview',
    'administer media',
    'administer media fields',
    'administer media form display',
    'administer media display',
    'administer media types',
    'view media',
    'access content overview',
    'view all revisions',
    'administer content types',
    'administer node fields',
    'administer node form display',
    'administer node display',
    'bypass node access',
  ];

  /**
   * An admin test user account.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $adminUser;

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = [
    'system',
    'node',
    'field_ui',
    'views',
    'views_ui',
    'block',
    'taxonomy',
    'file',
    'media_library',
    'user',
    'media_folders',
  ];

  /**
   * Set default theme to stable.
   *
   * @var string
   */
  protected $defaultTheme = 'stable9';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->drupalPlaceBlock('local_actions_block');
    $this->drupalPlaceBlock('local_tasks_block');

    $term_values = [
      'parent' => [0],
      'name' => 'Test',
      'description' => '',
      'vid' => 'media_folders_folder',
    ];
    $term = Term::create($term_values);
    $term->save();

    $fileMediaType = $this->createMediaType('file', [
      'id' => 'document',
      'label' => 'Document',
    ]);

    $fileMedia = $this->generateMedia('test.pdf', $fileMediaType);
    $fileMedia->save();

    $this->adminUser = $this->drupalCreateUser(static::$adminUserPermissions);
    $this->drupalLogin($this->adminUser);

    $this->drupalCreateContentType(['type' => 'page', 'name' => 'Page']);
  }

  /**
   * Tests that the Media folders's widget selection works as expected.
   */
  public function testWidgetSelection(): void {
    $assert_session = $this->assertSession();
    $page = $this->getSession()->getPage();

    $this->drupalGet('/admin/structure/types/manage/page/fields/add-field');
    $initial_edit = [
      'new_storage_type' => 'field_ui:entity_reference:media',
    ];
    $second_edit = [
      'label' => 'Media',
    ];
    $this->submitForm($initial_edit, 'Continue');
    $this->submitForm($second_edit, 'Continue');
    $assert_session->fieldExists('settings[handler_settings][target_bundles][document]')->check();
    $assert_session->assertWaitOnAjaxRequest();
    $page->pressButton('Save settings');

    $this->drupalGet('/admin/structure/types/manage/page/form-display');
    $assert_session->pageTextContains('View mode: List view');

    $this->drupalGet('/admin/structure/types/manage/page/display');
    $assert_session->pageTextContains('field_media');
    $page->pressButton('Show row weights');
    $page->fillField('fields[field_media][region]', 'content');
    $page->fillField('fields[field_media][type]', 'media_folders');
    $page->pressButton('Save');

    $this->drupalGet('/node/add/page');
    $assert_session->responseContains('type="submit" id="edit-field-media-open-button" name="field_media-media-folders-open-button" value="Add media"');
    $page->fillField('title[0][value]', 'Test');
    $page->pressButton('Add media');
    $assert_session->assertWaitOnAjaxRequest();
    $this->assertNotEmpty($assert_session->waitForElementVisible('css', '#drupal-modal'));
    $assert_session->responseContains('<div id="media-folders" class="widget');
    $assert_session->responseContains('<div class="folder folder-folder" data-id="1" data-uuid');

    $this->click('#explorer #navbar > ul li > div[data-id="1"] > a');
    $assert_session->assertWaitOnAjaxRequest();
    $assert_session->responseContains('<div class="folder folder-file" data-id="1" data-uuid');
    $this->click('.folder-file[data-id="1"] a.folder-icon');
    $page->pressButton('Insert selected');
    $this->assertNotEmpty($assert_session->waitForElementRemoved('css', '#drupal-modal'));
    $assert_session->assertWaitOnAjaxRequest();
    $assert_session->responseNotContains('<div id="media-folders" class="widget');
    $page->pressButton('Save');
    $assert_session->addressEquals('node/1');
    $this->drupalGet('/node/1');
    $assert_session->responseContains('<span class="file file--mime-application-pdf file--application-pdf">');
  }

  /**
   * Helper to generate a media item.
   *
   * @param string $filename
   *   String filename with extension.
   * @param \Drupal\media\MediaTypeInterface $media_type
   *   The media type.
   *
   * @return \Drupal\media\Entity\Media
   *   A media item.
   */
  protected function generateMedia($filename, MediaTypeInterface $media_type) {
    vfsStream::setup('drupal_root');
    vfsStream::create([
      'sites' => [
        'default' => [
          'files' => [
            $filename => str_repeat('a', 3000),
          ],
        ],
      ],
    ]);

    $file = File::create([
      'uri' => 'public://' . $filename,
    ]);
    $file->setPermanent();
    $file->save();

    return Media::create([
      'bundle' => $media_type->id(),
      'name' => $filename,
      'field_media_file' => [
        'target_id' => $file->id(),
      ],
      'field_folders_folder' => [
        'target_id' => 1,
      ],
    ]);
  }

}
